Learn R Programming

tsfa (version 2006.2-1)

nfactors: Extract the Number of Time Series Factors from an Object

Description

Extract the number of time series factors from an object.

Usage

nfactors(x)
    ## S3 method for class 'TSFmodel':
nfactors(x)
    ## S3 method for class 'TSFestModel':
nfactors(x)
    ## S3 method for class 'TSFfactors':
nfactors(x)
    ## S3 method for class 'EstEval':
nfactors(x)

Arguments

x
an object.

Value

  • an integer.

concept

TSFA

See Also

factors, factorNames, TSFmodel,